[![License](https://img.shields.io/badge/License-Apache%202.0-blue.svg)](https://opensource.org/licenses/Apache-2.0)
![build workflow](https://github.com/CareBT/carebt_core/actions/workflows/python-app.yml/badge.svg)
[![Test Coverage](https://api.codeclimate.com/v1/badges/05295e461f7a98edb412/test_coverage)](https://codeclimate.com/github/careBT/carebt_core/test_coverage)
[![Documentation Status](https://readthedocs.org/projects/carebt/badge/?version=latest)](https://carebt.readthedocs.io/en/latest/?badge=latest)
[![Maintainability](https://api.codeclimate.com/v1/badges/05295e461f7a98edb412/maintainability)](https://codeclimate.com/github/careBT/carebt_core/maintainability)
[![PyPI version fury.io](https://badge.fury.io/py/carebt.svg)](https://pypi.python.org/pypi/carebt/)

# careBT - contingency aware Behavior Trees

## About

A Python library offering a Behavior Tree implementation which focuses on contingency handling - the key to
master complex applications which operate in dynamic worlds.

## Documentation

Documentation can be found at [https://carebt.readthedocs.io/](https://carebt.readthedocs.io/)

## Contacts

Andreas Steck - <steck.andi@gmail.com>
